Discover Packages
github.com/Arsolitt/goxsub
format
package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Podkop converts proxies to uci shell commands for podkop OpenWrt package.
Returns a slice of command lines.
Singbox converts proxies to sing-box outbound JSON object strings.
Returns a slice where each element is a single JSON object (no trailing comma, no array wrapping).
type SingboxConfig struct {
OutboundPrefix string
OutboundSuffix string
DNSResolver string
}
SingboxConfig holds options for sing-box outbound generation.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.