Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Proxy ¶
Proxy is the interface implemented by all protocol-specific proxy types.
func ExtractProxies ¶
func ExtractProxies(subs []sub.Subscription) []Proxy
ExtractProxies extracts proxy outbounds from subscriptions by protocol and tag. Currently supports "vless" protocol and "proxy" tag.
func FilterByRemark ¶
FilterByRemark returns proxies whose Remarks field does not match any of the given glob patterns. Matching is case-insensitive. If patterns is empty, all proxies are returned unchanged.
type VLESSProxy ¶
VLESSProxy represents a VLESS protocol proxy extracted from a subscription.
func (*VLESSProxy) Protocol ¶
func (v *VLESSProxy) Protocol() string
func (*VLESSProxy) Remarks ¶
func (v *VLESSProxy) Remarks() string
func (*VLESSProxy) SetRemarks ¶ added in v1.1.0
func (v *VLESSProxy) SetRemarks(r string)
SetRemarks updates the proxy remark.
func (*VLESSProxy) Tag ¶
func (v *VLESSProxy) Tag() string
Click to show internal directories.
Click to hide internal directories.